@@ -1,4 +1,5 @@
 from ..stage import GraderStage, Registrar
+from ..task import GenericResult
 from .check import CheckResult
 from .build import BuildResult
 
@@ -8,6 +9,11 @@ class SetupStage(GraderStage):
 
     name = "setup"
 
+    def generic(self, **details) -> Registrar:
+        """Generic tasks."""
+
+        return self.create_registrar(details, GenericResult)
+
     def build(self, **details) -> Registrar:
         """Compilation."""
 
