@@ -1,4 +1,5 @@
 from ..stage import GraderStage, Registrar
+from ..task import GenericResult
 from .cleanup import CleanupResult
 
 
@@ -7,6 +8,11 @@ class TeardownStage(GraderStage):
 
     name = "teardown"
 
+    def generic(self, **details) -> Registrar:
+        """Generic tasks."""
+
+        return self.create_registrar(details, GenericResult)
+
     def cleanup(self, **details) -> Registrar:
         """Deleting files."""
 
