@@ -2,6 +2,7 @@ import subprocess
 import timeit
 import os
 import time
+import signal
 
 try:
     import fcntl
@@ -11,6 +12,7 @@ except ImportError:
 from typing import Optional, Tuple, Callable, IO
 from dataclasses import dataclass, asdict, field
 from contextlib import contextmanager
+from pathlib import Path
 
 
 @dataclass(eq=False)
@@ -39,6 +41,7 @@ class Interaction:
     """Container for single interaction with a process."""
 
     args: Tuple[str, ...]
+    cwd: Optional[Path]
 
     elapsed: Optional[float] = None
     stdin: Optional[bytes] = None
@@ -52,6 +55,8 @@ class Interaction:
         for field_name in "stdout", "stdin", "stderr":
             if dump[field_name] is not None:
                 dump[field_name] = dump[field_name].decode(errors="replace")
+        if dump["cwd"]:
+            dump["cwd"] = str(dump["cwd"])
         return dump
 
 
@@ -67,14 +72,6 @@ class Runtime(Interaction):
     raised_exception: bool = False
     exception: Optional[RuntimeException] = None
 
-    def dump(self) -> dict:
-        """Make the runtime JSON serializable."""
-
-        dump = super().dump()
-        if dump["exception"] is not None:
-            dump["exception"] = dump["exception"].dump()
-        return dump
-
 
 class InteractiveStreamTimeoutExpired(RuntimeError):
     buffer: bytes
@@ -184,13 +181,14 @@ class Interactive:
     _args: Tuple[str, ...]
     _process: subprocess.Popen
     _start_time: float
+    cwd: Optional[Path]
     stdin: InteractiveStream
     stdout: InteractiveStream
     stderr: InteractiveStream
 
     _recording: Optional[Interaction] = None
 
-    def __init__(self, args: Tuple[str, ...]):
+    def __init__(self, args: Tuple[str, ...], cwd: Path = None):
         """Start up the new process."""
 
         self._args = args
@@ -199,7 +197,9 @@ class Interactive:
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             stdin=subprocess.PIPE,
-            preexec_fn=config.process_setup)
+            preexec_fn=config.process_setup,
+            cwd=str(cwd) if cwd is not None else None)
+        self.cwd = cwd
         self.stdin = InteractiveStream(self._process.stdin, read=False, write=True)
         self.stdout = InteractiveStream(self._process.stdout, read=True, write=False)
         self.stderr = InteractiveStream(self._process.stdout, read=True, write=False)
@@ -251,6 +251,7 @@ class Interactive:
         stop_time = timeit.default_timer()
         return Runtime(
             args=self._args,
+            cwd=self.cwd,
             timeout=timeout,
             code=self._process.returncode,
             elapsed=stop_time - self._start_time,
@@ -313,7 +314,7 @@ class SubprocessConfiguration:
 config = SubprocessConfiguration()
 
 
-def run(*args: str, stdin: bytes = None, timeout: float = None) -> Runtime:
+def run(*args: str, stdin: bytes = None, timeout: float = None, cwd: Path = None) -> Runtime:
     """Run an executable with a list of command line arguments.
 
     The provided path must be absolute in order to properly execute
@@ -332,24 +333,26 @@ def run(*args: str, stdin: bytes = None, timeout: float = None) -> Runtime:
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
                 stdin=subprocess.PIPE,
-                preexec_fn=config.process_setup)
+                preexec_fn=config.process_setup,
+                cwd=str(cwd) if cwd is not None else None)
         else:
             process = subprocess.Popen(
                 args,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
-                preexec_fn=config.process_setup)
+                preexec_fn=config.process_setup,
+                cwd=str(cwd) if cwd is not None else None)
 
     # Catch common errors
     except OSError as error:
         exception = RuntimeException.from_os_error(error)
-        return Runtime(args=args, timeout=timeout, stdin=stdin, raised_exception=True, exception=exception)
+        return Runtime(args=args, cwd=cwd, timeout=timeout, stdin=stdin, raised_exception=True, exception=exception)
     except ValueError:
         exception = RuntimeException(description="failed to open process")
-        return Runtime(args=args, timeout=timeout, stdin=stdin, raised_exception=True, exception=exception)
+        return Runtime(args=args, cwd=cwd, timeout=timeout, stdin=stdin, raised_exception=True, exception=exception)
     except subprocess.SubprocessError as exception:
         exception = RuntimeException(description=str(exception))
-        return Runtime(args=args, timeout=timeout, stdin=stdin, raised_exception=True, exception=exception)
+        return Runtime(args=args, cwd=cwd, timeout=timeout, stdin=stdin, raised_exception=True, exception=exception)
 
     # Wait for the process to finish with timeout
     start = timeit.default_timer()
@@ -357,13 +360,20 @@ def run(*args: str, stdin: bytes = None, timeout: float = None) -> Runtime:
         stdout, stderr = process.communicate(input=stdin, timeout=timeout)
     except subprocess.TimeoutExpired:
         process.kill()
-        stdout, stderr = process.communicate()
-        return Runtime(args=args, timeout=timeout, stdin=stdin, stdout=stdout, stderr=stderr, timed_out=True)
+
+        # Recover data
+        try:
+            stdout, stderr = process.communicate(timeout=1)
+        except subprocess.TimeoutExpired:
+            stdout, stderr = None, None
+
+        return Runtime(args=args, cwd=cwd, timeout=timeout, stdin=stdin, stdout=stdout, stderr=stderr, timed_out=True)
 
     # Check elapsed
     elapsed = timeit.default_timer() - start
     return Runtime(
         args=args,
+        cwd=cwd,
         timeout=timeout,
         code=process.returncode,
         elapsed=elapsed,
